@@ -104,7 +104,9 @@ class ShelfModelView(sqla.ModelView):
             :param sort_desc:
                 Ascending or descending
         """
-        if issubmodel(sort_field.mapper.class_, 'LocalizedString'):
+        if not hasattr(sort_field, "mapper"):
+            pass
+        elif issubmodel(sort_field.mapper.class_, 'LocalizedString'):
             table = sort_field.mapper.tables[0]
 
             query = query.outerjoin(str(sort_field).split('.')[1])
@@ -117,7 +119,7 @@ class ShelfModelView(sqla.ModelView):
 
             return query, joins
 
-        if issubmodel(sort_field.mapper.class_, 'RemoteFile'):
+        elif issubmodel(sort_field.mapper.class_, 'RemoteFile'):
             table = sort_field.mapper.tables[0]
 
             query = query.outerjoin(str(sort_field).split('.')[1])
@@ -130,7 +132,7 @@ class ShelfModelView(sqla.ModelView):
 
             return query, joins
 
-        if issubmodel(sort_field.mapper.class_, 'Picture'):
+        elif issubmodel(sort_field.mapper.class_, 'Picture'):
             table = sort_field.mapper.tables[0]
 
             query = query.outerjoin(str(sort_field).split('.')[1])
